<?php
namespace App\Services;

use Illuminate\Support\Facades\Http;
use Illuminate\Support\Facades\Log;
use Illuminate\Support\Facades\View;

class MailSenderService
{
    /**
     * Send an email using an external API with a Blade template.
     *
     * @param  string  $fromEmail
     * @param  string|array  $toEmails
     * @param  string  $subject
     * @param  string  $bladeTemplate
     * @param  array  $templateData
     * @return array
     */
    public function sendEmail($fromEmail, $toEmails, $subject, $bladeTemplate, $templateData = [])
    {
        // Check if $toEmails is an array and convert it to a comma-separated string
        if (is_array($toEmails)) {
            $toEmails = implode(',', $toEmails);  // Convert array to comma-separated string
        }

        // Render the Blade template into an HTML string
        $htmlBody = view($bladeTemplate, $templateData)->render(); // Render the Blade template

        // Prepare the email data
        $emailData = [
        'email' => $fromEmail,  // Sender's email
        'to' => $toEmails,      // Comma-separated string of recipient emails
        'subject' => $subject,  // Subject of the email
        'body' => $htmlBody,    // Rendered HTML content of the email
        'isHtml' => true,       // Ensure the content is treated as HTML (check if supported by the API)
    ];

        // Send the email using the external API
        try {
            $response = Http::post('https://openapi.anlook.com/api/Email/v2/sendEmail', $emailData);

            // Log the response for debugging purposes
            Log::info('Email sent via external API', ['response' => $response->json()]);

            // Check if the API request was successful
            if ($response->successful()) {
                return [
                    'status' => 'success',
                    'message' => 'Email sent successfully',
                ];
            } else {
                Log::error('Email sending failed', ['error' => $response->json()]);
                return [
                    'status' => 'error',
                    'message' => 'Failed to send email via external API',
                ];
            }
        } catch (\Exception $e) {
            // Log the exception if the API call fails
            Log::error('Email API request failed', ['error' => $e->getMessage()]);
            return [
                'status' => 'error',
                'message' => 'Failed to send email due to an error: ' . $e->getMessage(),
            ];
        }
    }
}
